
.. _`WBEM server library`:

WBEM server library
===================

.. index:: pair: WBEM server library; indications
.. index:: pair: WBEM server library; indication subscriptions
.. index:: pair: libraries; WBEM Server library

.. automodule:: pywbem._server


.. _`WBEMServer`:

WBEMServer
^^^^^^^^^^

.. autoclass:: pywbem.WBEMServer
    :members:
    :special-members:
    :exclude-members: __init__,__weakref__
    :autosummary:
    :autosummary-inherited-members:
